@@ -18,6 +18,7 @@ from mlflow.entities.run_info import RunInfo
 from mlflow.entities.run_log import RunLog
 from mlflow.entities.run_status import RunStatus
 from mlflow.entities.run_tag import RunTag
+from mlflow.entities.sentinel import SENTINEL
 from mlflow.entities.source_type import SourceType
 from mlflow.entities.view_type import ViewType
 
@@ -41,4 +42,5 @@ __all__ = [
     "EntitySubjectRole",
     "Columns",
     "RunLog",
+    "SENTINEL",
 ]
