@@ -1,8 +1,4 @@
-from mlflow.entities import (
-    SubjectType,
-    EntityType,
-    Role,
-)
+from mlflow.entities import EntityType, Role, SubjectType
 from mlflow.protos.service_pb2 import SubjectRoles as ProtoEntitySubjectRoles
 
 
