@@ -22,6 +22,7 @@ class Experiment(_MLflowObject):
         owner_subject_id=None,
         num_runs=None,
         num_user_collaborators=None,
+        description=None,
     ):
         super().__init__()
         self._experiment_id = experiment_id
@@ -33,6 +34,7 @@ class Experiment(_MLflowObject):
         self._owner_subject_id = owner_subject_id
         self._num_runs = num_runs
         self._num_user_collaborators = num_user_collaborators
+        self._description = description
 
     @property
     def experiment_id(self):
@@ -82,6 +84,10 @@ class Experiment(_MLflowObject):
     def _add_tag(self, tag):
         self._tags[tag.key] = tag.value
 
+    @property
+    def description(self):
+        return self._description
+
     @classmethod
     def from_proto(cls, proto):
         experiment = cls(
@@ -93,6 +99,7 @@ class Experiment(_MLflowObject):
             owner_subject_id=proto.owner_subject_id,
             num_runs=proto.num_runs,
             num_user_collaborators=proto.num_user_collaborators,
+            description=proto.description,
         )
         for proto_tag in proto.tags:
             experiment._add_tag(ExperimentTag.from_proto(proto_tag))
@@ -111,4 +118,5 @@ class Experiment(_MLflowObject):
         experiment.owner_subject_id = self.owner_subject_id
         experiment.num_runs = self.num_runs
         experiment.num_user_collaborators = self.num_user_collaborators
+        experiment.description = self.description or ""
         return experiment
