@@ -1,10 +1,9 @@
-from datetime import datetime
-from functools import lru_cache
 import os
-from mimetypes import guess_type
-
 import posixpath
 import urllib.parse
+from datetime import datetime
+from functools import lru_cache
+from mimetypes import guess_type
 
 from mlflow import data
 from mlflow.entities import FileInfo
@@ -12,7 +11,6 @@ from mlflow.exceptions import MlflowException
 from mlflow.store.artifact.artifact_repo import ArtifactRepository
 from mlflow.utils.file_utils import relative_path_to_artifact_path
 
-
 _MAX_CACHE_SECONDS = 300
 
 
@@ -207,3 +205,14 @@ class S3ArtifactRepository(ArtifactRepository):
                 listed_object_path=file_path, artifact_path=dest_path
             )
             s3_client.delete_object(Bucket=bucket, Key=file_path)
+
+    def get_read_signed_uri(self, artifact_path: str, expires_in: int = 1800) -> str:
+        if not artifact_path:
+            raise MlflowException("artifact_path must be notn empty string")
+        (bucket, s3_root_path) = data.parse_s3_uri(self.artifact_uri)
+        s3_client = self._get_s3_client()
+        key = posixpath.join(s3_root_path, artifact_path)
+
+        return s3_client.generate_presigned_url(
+            "get_object", Params={"Bucket": bucket, "Key": key}, ExpiresIn=expires_in
+        )
