@@ -1,7 +1,7 @@
 import typing
 from abc import ABCMeta, abstractmethod
 
-from mlflow.entities import Columns, Metric, RunLog, ViewType
+from mlflow.entities import Columns, Metric, Run, RunLog, ViewType
 from mlflow.store.entities.paged_list import PagedList
 from mlflow.store.tracking import SEARCH_MAX_RESULTS_DEFAULT
 
@@ -41,7 +41,7 @@ class AbstractStore:
         pass
 
     @abstractmethod
-    def create_experiment(self, name, artifact_location, tags):
+    def create_experiment(self, name, artifact_location, tags, description):
         """
         Create a new experiment.
         If an experiment with the given name already exists, throws exception.
@@ -131,7 +131,7 @@ class AbstractStore:
         pass
 
     @abstractmethod
-    def update_run_info(self, run_id, run_status, end_time):
+    def update_run_info(self, run_id, run_status, end_time, description):
         """
         Update the metadata of the specified run.
 
@@ -140,7 +140,7 @@ class AbstractStore:
         pass
 
     @abstractmethod
-    def create_run(self, experiment_id, user_id, start_time, tags, name):
+    def create_run(self, experiment_id, user_id, start_time, tags, name, description):
         """
         Create a run under the specified experiment ID, setting the run's status to "RUNNING"
         and the start time to the current time.
@@ -347,3 +347,9 @@ class AbstractStore:
         self, run_uuid: str, key: typing.Optional[str], log_type: typing.Optional[str]
     ) -> typing.List[RunLog]:
         raise NotImplementedError()
+
+    def get_run_by_fqn(self, fqn: str) -> Run:
+        raise NotImplementedError()
+
+    def update_experiment(self, experiment_id: str, description: typing.Optional[str]):
+        raise NotImplementedError()
