@@ -1,13 +1,15 @@
 import json
 import logging
 import os
-import sys
 import shutil
-
+import sys
 import uuid
 
+import mlflow.protos.databricks_pb2 as databricks_pb2
 from mlflow.entities import (
+    SENTINEL,
     Experiment,
+    ExperimentTag,
     Metric,
     Param,
     Run,
@@ -15,54 +17,52 @@ from mlflow.entities import (
     RunInfo,
     RunStatus,
     RunTag,
-    ViewType,
     SourceType,
-    ExperimentTag,
+    ViewType,
 )
 from mlflow.entities.lifecycle_stage import LifecycleStage
 from mlflow.entities.run_info import check_run_is_active, check_run_is_deleted
-from mlflow.exceptions import MlflowException, MissingConfigException
-import mlflow.protos.databricks_pb2 as databricks_pb2
+from mlflow.exceptions import MissingConfigException, MlflowException
 from mlflow.protos.databricks_pb2 import INTERNAL_ERROR, RESOURCE_DOES_NOT_EXIST
 from mlflow.store.tracking import (
     DEFAULT_LOCAL_FILE_AND_ARTIFACT_PATH,
     SEARCH_MAX_RESULTS_THRESHOLD,
 )
 from mlflow.store.tracking.abstract_store import AbstractStore
+from mlflow.utils.env import get_env
+from mlflow.utils.file_utils import (
+    append_to,
+    exists,
+    find,
+    get_parent_dir,
+    is_directory,
+    list_all,
+    list_subdirs,
+    local_file_uri_to_path,
+    make_containing_dirs,
+    mkdir,
+    mv,
+    path_to_local_file_uri,
+    read_file,
+    read_file_lines,
+    read_yaml,
+    write_to,
+    write_yaml,
+)
+from mlflow.utils.mlflow_tags import MLFLOW_LOGGED_MODELS
+from mlflow.utils.string_utils import is_string_type
+from mlflow.utils.uri import append_to_uri_path
 from mlflow.utils.validation import (
+    _validate_batch_log_data,
+    _validate_batch_log_limits,
+    _validate_experiment_id,
+    _validate_list_experiments_max_results,
     _validate_metric_name,
+    _validate_param_keys_unique,
     _validate_param_name,
     _validate_run_id,
     _validate_tag_name,
-    _validate_experiment_id,
-    _validate_batch_log_limits,
-    _validate_batch_log_data,
-    _validate_list_experiments_max_results,
-    _validate_param_keys_unique,
 )
-from mlflow.utils.env import get_env
-from mlflow.utils.file_utils import (
-    is_directory,
-    list_subdirs,
-    mkdir,
-    exists,
-    write_yaml,
-    read_yaml,
-    find,
-    read_file_lines,
-    read_file,
-    write_to,
-    append_to,
-    make_containing_dirs,
-    mv,
-    get_parent_dir,
-    list_all,
-    local_file_uri_to_path,
-    path_to_local_file_uri,
-)
-from mlflow.utils.string_utils import is_string_type
-from mlflow.utils.uri import append_to_uri_path
-from mlflow.utils.mlflow_tags import MLFLOW_LOGGED_MODELS
 
 _TRACKING_DIR_ENV_VAR = "MLFLOW_TRACKING_DIR"
 
@@ -246,8 +246,8 @@ class FileStore(AbstractStore):
                  :py:class:`Experiment <mlflow.entities.Experiment>` objects. The pagination token
                  for the next page can be obtained via the ``token`` attribute of the object.
         """
-        from mlflow.utils.search_utils import SearchUtils
         from mlflow.store.entities.paged_list import PagedList
+        from mlflow.utils.search_utils import SearchUtils
 
         _validate_list_experiments_max_results(max_results)
         self._check_root_dir()
@@ -319,7 +319,7 @@ class FileStore(AbstractStore):
                     databricks_pb2.RESOURCE_ALREADY_EXISTS,
                 )
 
-    def create_experiment(self, name, artifact_location=None, tags=None):
+    def create_experiment(self, name, artifact_location=None, tags=None, description=None):
         self._check_root_dir()
         self._validate_experiment_name(name)
         # Get all existing experiments and find the one with largest numerical ID.
@@ -477,7 +477,7 @@ class FileStore(AbstractStore):
             return os.path.basename(os.path.abspath(experiment_dir)), runs[0]
         return None, None
 
-    def update_run_info(self, run_id, run_status, end_time):
+    def update_run_info(self, run_id, run_status, end_time, description=SENTINEL):
         _validate_run_id(run_id)
         run_info = self._get_run_info(run_id)
         check_run_is_active(run_info)
@@ -485,7 +485,7 @@ class FileStore(AbstractStore):
         self._overwrite_run_info(new_info)
         return new_info
 
-    def create_run(self, experiment_id, user_id, start_time, tags, name):
+    def create_run(self, experiment_id, user_id, start_time, tags, name, description=None):
         """
         Creates a run with the specified attributes.
         """
