@@ -13,6 +13,7 @@ from mlflow.entities import (
     ExperimentTag,
     Metric,
     Param,
+    Run,
     RunLog,
     RunStatus,
     RunTag,
@@ -88,7 +89,7 @@ class TrackingServiceClient:
         """
         return self.store.get_metric_history(run_id=run_id, metric_key=key)
 
-    def create_run(self, experiment_id, start_time=None, tags=None, name=""):
+    def create_run(self, experiment_id, start_time=None, tags=None, name="", description=None):
         """
         Create a :py:class:`mlflow.entities.Run` object that can be associated with
         metrics, parameters, artifacts, etc.
@@ -116,6 +117,7 @@ class TrackingServiceClient:
             start_time=start_time or int(time.time() * 1000),
             tags=[RunTag(key, value) for (key, value) in tags.items()],
             name=name,
+            description=description,
         )
 
     def list_run_infos(
@@ -176,7 +178,7 @@ class TrackingServiceClient:
         """
         return self.store.get_experiment_by_name(name, owner_subject_id=owner_subject_id)
 
-    def create_experiment(self, name, artifact_location=None, tags=None):
+    def create_experiment(self, name, artifact_location=None, tags=None, description=None):
         """Create an experiment.
 
         :param name: The experiment name. Must be unique.
@@ -193,6 +195,7 @@ class TrackingServiceClient:
             name=name,
             artifact_location=artifact_location,
             tags=[ExperimentTag(key, value) for (key, value) in tags.items()] if tags else [],
+            description=description,
         )
 
     def delete_experiment(self, experiment_id):
@@ -219,6 +222,9 @@ class TrackingServiceClient:
         """
         self.store.rename_experiment(experiment_id, new_name)
 
+    def update_experiment(self, experiment_id, description):
+        self.store.update_experiment(experiment_id, description)
+
     def log_metric(self, run_id, key, value, timestamp=None, step=None):
         """
         Log a metric against the run ID.
@@ -409,9 +415,14 @@ class TrackingServiceClient:
         end_time = end_time if end_time else int(time.time() * 1000)
         status = status if status else RunStatus.to_string(RunStatus.FINISHED)
         self.store.update_run_info(
-            run_id, run_status=RunStatus.from_string(status), end_time=end_time
+            run_id,
+            run_status=RunStatus.from_string(status),
+            end_time=end_time,
         )
 
+    def update_run(self, run_id: str, description: str):
+        self.store.update_run_info(run_id, description=description)
+
     def delete_run(self, run_id):
         """
         Deletes a run with the given ID.
@@ -473,3 +484,6 @@ class TrackingServiceClient:
         self, run_uuid: str, key: typing.Optional[str] = None, log_type: typing.Optional[str] = None
     ) -> typing.List[RunLog]:
         return self.store.list_run_logs(run_uuid=run_uuid, key=key, log_type=log_type)
+
+    def get_run_by_fqn(self, fqn: str) -> Run:
+        return self.store.get_run_by_fqn(fqn=fqn)
